==> food-order-super-admin-2.0.9.zip: src/readme.md <==
# Frontend API Interface Specification

---

## Overview
This document outlines the frontend API contract required to interact with the backend PHP application. All operations are triggered via a single endpoint (function.php) using POST or GET requests, with the action defined in the action field. Role-based access is enforced via session variables.

---

## Role Definitions

```sql
INSERT INTO `user_role` (`pk_role_id`, `role_name`, `scope`) VALUES
(1, "SystemAdmin", "Platform"),
(2, "SupportAgent", "Platform"),
(3, "ContentModerator", "Platform"),
(4, "BusinessOwner", "Tenant"),
(5, "BusinessManager", "Tenant"),
(6, "Staff", "Tenant"),
(7, "Operator", "Tenant"),
(8, "Customer", "Public");
```

## API Summary Table

| Action                            | Method | Required Role      | Payload Object           | Description                                                            |
|-----------------------------------|--------|--------------------|--------------------------|------------------------------------------------------------------------|
| [`getPreAuthPayments`](#getPreAuthPayments)              | GET    |  2,4,5,6           |                          | Get a list of pre auth payment to decided to accept or reject          |
| [`acceptedRejectPreAuthPayment`](#acceptedRejectPreAuthPayment)    | POST   |  2,4,5,6           | foodOrder                | From a list of pre auth payment to decided to accept or reject         |
| [`getOrderList`](#getOrderList)                    | GET    |  2,4,5,6           |                          | View all orders that are active and any completed up to 2 hours old    |
| [`viewOrderDetails`](#viewOrderDetails)                | GET    |  2,4,5,6           |                          | View order details                                                     |
| [`updateStatusOrder`](#updateStatusOrder)               | POST   |  2,4,5,6           | foodOrder                | Update the Order Status                                                |
| [`updateStatusItem`](#updateStatusItem)| POST | 2,4,5,6 | foodOrderItem | Update the Order Item Status |
| [`viewOrdersByDateRange`](#viewOrdersByDateRange)| POST | 1,2,3 |  | View orders from all firms |




<a id="getPreAuthPayments"></a>
### `getPreAuthPayments`
```json
    "action" : "getPreAuthPayments",
```

<a id="acceptedRejectPreAuthPayment"></a>
### `acceptedRejectPreAuthPayment`
```json
    "action" : "acceptedRejectPreAuthPayment",
    "foodOrder'" : 
            [
                "id" : "int",
                "accepted" : int [1: Accept, 0:reject]
            ]
```

<a id="getOrderList"></a>
### `getOrderList`
```json
    "action" : "getOrderList",
```

<a id="viewOrderDetails"></a>
### `viewOrderDetails`
```json
    "action" : "viewOrderDetails",
    "orderId": "int" 
```

<a id="updateStatusOrder"></a>
### `updateStatusOrder`
```json
    "action" : "updateStatusOrder",
    "foodOrder" : [
        "id":"int", orderId
        "orderStatus":"string" ["cooking", "delivery", "completed"]
    ]
```

<a id="updateStatusItem"></a>
### `updateStatusItem`
```json
    "action" : "updateStatusItem",
    "foodOrderItem" : [
        "id":"int", itemId
        "itemStatus":"string" ["prepared", "served", "cancelled"]
    ]
```

<a id="viewOrdersByDateRange"></a>
### `viewOrdersByDateRange`
```json
    "action" : "viewOrdersByDateRange",
    "startDate" : "2024-01-01", optional, can included time 2024-01-01 00:00:00
    "endDate" :   "2024-12-31", optional, can included time 2024-12-31 23:59:58
```



## Payload Structures

==> food-order-super-admin-2.0.27.zip: src/readme.md <==
# Frontend API Interface Specification

---

## Overview
This document outlines the frontend API contract required to interact with the backend PHP application. All operations are triggered via a single endpoint (function.php) using POST or GET requests, with the action defined in the action field. Role-based access is enforced via session variables.

---

## Role Definitions

```sql
INSERT INTO `user_role` (`pk_role_id`, `role_name`, `scope`) VALUES
(1, "SystemAdmin", "Platform"),
(2, "SupportAgent", "Platform"),
(3, "ContentModerator", "Platform"),
(4, "BusinessOwner", "Tenant"),
(5, "BusinessManager", "Tenant"),
(6, "Staff", "Tenant"),
(7, "Operator", "Tenant"),
(8, "Customer", "Public");
```

## API Summary Table

| Action                            | Method | Required Role      | Payload Object           | Description                                                            |
|-----------------------------------|--------|--------------------|--------------------------|------------------------------------------------------------------------|
| [`getPreAuthPayments`](#getPreAuthPayments)              | GET    |  2,4,5,6           |                          | Get a list of pre auth payment to decided to accept or reject          |
| [`acceptedRejectPreAuthPayment`](#acceptedRejectPreAuthPayment)    | POST   |  2,4,5,6           | foodOrder                | From a list of pre auth payment to decided to accept or reject         |
| [`getOrderList`](#getOrderList)                    | GET    |  2,4,5,6           |                          | View all orders that are active and any completed up to 2 hours old    |
| [`viewOrderDetails`](#viewOrderDetails)                | GET    |  2,4,5,6           |                          | View order details                                                     |
| [`updateStatusOrder`](#updateStatusOrder)               | POST   |  2,4,5,6           | foodOrder                | Update the Order Status                                                |
| [`updateStatusItem`](#updateStatusItem)| POST | 2,4,5,6 | foodOrderItem | Update the Order Item Status |
| [`viewOrdersByDateRange`](#viewOrdersByDateRange)| POST | 1,2,3 |  | View orders from all firms |




<a id="getPreAuthPayments"></a>
### `getPreAuthPayments`
```json
    "action" : "getPreAuthPayments",
```

<a id="acceptedRejectPreAuthPayment"></a>
### `acceptedRejectPreAuthPayment`
```json
    "action" : "acceptedRejectPreAuthPayment",
    "foodOrder'" : 
            [
                "id" : "int",
                "accepted" : int [1: Accept, 0:reject]
            ]
```

<a id="getOrderList"></a>
### `getOrderList`
```json
    "action" : "getOrderList",
```

<a id="viewOrderDetails"></a>
### `viewOrderDetails`
```json
    "action" : "viewOrderDetails",
    "orderId": "int" 
```

<a id="updateStatusOrder"></a>
### `updateStatusOrder`
```json
    "action" : "updateStatusOrder",
    "foodOrder" : [
        "id":"int", orderId
        "orderStatus":"string" ["cooking", "delivery", "completed"]
    ]
```

<a id="updateStatusItem"></a>
### `updateStatusItem`
```json
    "action" : "updateStatusItem",
    "foodOrderItem" : [
        "id":"int", itemId
        "itemStatus":"string" ["prepared", "served", "cancelled"]
    ]
```

<a id="viewOrdersByDateRange"></a>
### `viewOrdersByDateRange`
```json
    "action" : "viewOrdersByDateRange",
    "startDate" : "2024-01-01", optional, can included time 2024-01-01 00:00:00
    "endDate" :   "2024-12-31", optional, can included time 2024-12-31 23:59:58
```


## Payment Status Definitions
| Payment Type                            | Description |
|-----------------------------------------|-------------|
| payment_intent | Not passed payment details |
| payment_pre_auth | Payment details are pre-authorized card payment details taken but not yet captured |
| paid | Payment has been successfully captured |
| partial_refund | Payment has been partially refunded |
| refunded | Payment has been fully refunded |
| unpaid | Payment has not gone through or cancelled |


## Payload Structures
